*-----------------------------------------------------------------------
*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved.
*-----------------------------------------------------------------------
      CHARACTER(3) FUNCTION USGI(IC)

      USGI='\x'//CHAR(IC)

      END
